# Install required packages
if(!("ade4" %in% installed.packages()[,1])){install.packages("ade4")}
if(!("Cairo" %in% installed.packages()[,1])){install.packages("Cairo")}
if(!("SuppDists" %in% installed.packages()[,1])){install.packages("SuppDists")}
if(!("R2HTML" %in% installed.packages()[,1])){install.packages("R2HTML")}

# Provide path for the datasets, must be a writable directory to enable outputs export
DataPath <- "The_Path_to_the_data_directory"
setwd(DataPath)

# Create directory for graphical output
dir.create(paste(DataPath,"Graphs\\",sep=""))

# Importing data in R
biovol_Full <- read.csv2("MARS-SEPT06BIOVOL.TXT")
phyto_Full <- read.csv2("MARS-SEPT06PHYTO.TXT")
biovol_classes_import <- read.csv2("Classes_phyto.TXT")
codes <- read.csv2("Codes.TXT")

# Selecting species according to paragraph 2
seuilbiovol <- 0.0001
seuilphyto <- 0.0001

Abond_subset <- c(T,sapply((phyto_Full)[,-1],sum,na.rm=T)/sum((phyto_Full)[,-1],na.rm=T)>=seuilphyto)
names(Abond_subset) <- c("Code",names(Abond_subset)[-1])
Biovol_subset <- c(T,sapply((biovol_Full)[,-1],sum,na.rm=T)/sum((biovol_Full)[,-1],na.rm=T)>=seuilbiovol) 
names(Biovol_subset) <- c("Code",names(Biovol_subset)[-1])

any(is.na(biovol_Full))
any(is.na(phyto_Full))
any(is.na(codes))

biovol <- subset(biovol_Full,select=((Abond_subset==T) & (Biovol_subset==T)))
(ncolbiovol <- dim(biovol)[2])
(nrowbiovol <- (dim(biovol)[1]))
(name1 <- names(biovol))

biovol_classes <- subset(biovol_classes_import,subset=Phyto %in% names(biovol))
biovol_classes[,"Phyto"] <- as.factor(as.character(biovol_classes[,"Phyto"]))

couleurs_classes <- as.vector(biovol_classes[,"Color"])
couleurs_classes 

as.character((biovol_classes[,"Phyto"]))==colnames(biovol)[-1]

biovol3m <- data.frame(t(t(biovol[,2:ncolbiovol])))

(datesdates <- c("06/03/2006","04/04/2006","03/05/2006","07/06/2006","28/06/2006","04/07/2006","24/07/2006","07/08/2006","22/08/2006","05/09/2006","19/09/2006"))
(ndates <- length(datesdates))
(stationsstations <- c("G","H","I","J","K","N"))
(nstations <- length(stationsstations))


# Describing the species
library(ade4)   # Load ade4 library

dir.create(paste(DataPath,"Graphs\\TableCont\\",sep=""))
setwd(paste(DataPath,"Graphs\\TableCont\\",sep=""))

source(paste(DataPath,"progs.R",sep="")) # Load user customized plotting functions
library(Cairo)  # Load Cairo library for exporting graphics

par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))
# Screen output
par(mfrow = c(1,1))
for (j in 1:(ncolbiovol-1)) {
temptab=NULL
for (i in 0:(ndates-1)) {temptab <- cbind(temptab,(biovol3m)[(1+i*nstations):((i+1)*nstations),j])}
rownames(temptab) <- stationsstations
colnames(temptab) <- datesdates
table.cont(temptab, abmean.x = FALSE, csi = 2, abline.x = FALSE, coul_rec=couleurs_classes[j], 
    clabel.r = 2, clabel.c = 1.5, clegend=0, col.labels=datesdates)
scatterutil.sub(colnames(biovol3m)[j], csub = 1.5, possub = "topleft")
}
par(mfrow = c(1,1))
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

# Files output
if(FALSE){
# Save figures as .png, .pdf and .eps
for (j in 1:(ncolbiovol-1)) {
temptab=NULL
for (i in 0:(ndates-1)) {temptab <- cbind(temptab,(biovol3m)[(1+i*nstations):((i+1)*nstations),j])}
rownames(temptab) <- stationsstations
colnames(temptab) <- datesdates
Cairo(800, 980, file=paste(colnames(biovol3m)[j],".png",sep=""), type="png", bg="white", pointsize=16)
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))
table.cont(temptab, abmean.x = FALSE, csi = 2, abline.x = FALSE, coul_rec=couleurs_classes[j], clabel.r = 2, clabel.c = 1.5, clegend=0, col.labels=datesdates)
scatterutil.sub(colnames(biovol3m)[j], csub = 1.5, possub = "topleft")
dev.off() # creates a .png file with the above plot
Cairo(4800, 4800, file=paste(colnames(biovol3m)[j],".pdf",sep=""), type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))
table.cont(temptab, abmean.x = FALSE, csi = 2, abline.x = FALSE, coul_rec=couleurs_classes[j], clabel.r = 2, clabel.c = 1, clegend=0, col.labels=datesdates)
scatterutil.sub(colnames(biovol3m)[j], csub = 1.5, possub = "topleft")
dev.off() # creates a .pdf file with the above plot
Cairo(4800, 4800, file=paste(colnames(biovol3m)[j],sep=""), type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))
table.cont(temptab, abmean.x = FALSE, csi = 2, abline.x = FALSE, coul_rec=couleurs_classes[j], clabel.r = 2, clabel.c = 1, clegend=0, col.labels=datesdates)
scatterutil.sub(colnames(biovol3m)[j], csub = 1.5, possub = "topleft")
dev.off() # creates a .eps file with the above plot
}
par(mfrow = c(1,1))    
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))
}


# Files output for Figures 7, 8, 9 and 10
for (j in (c(111,96,50,62)+1)) {
temptab=NULL
for (i in 0:(ndates-1)) {temptab <- cbind(temptab,(biovol3m)[(1+i*nstations):((i+1)*nstations),j])}
rownames(temptab) <- stationsstations
colnames(temptab) <- datesdates
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))
table.cont(temptab, abmean.x = FALSE, csi = 2, abline.x = FALSE, coul_rec=couleurs_classes[j], clabel.r = 2, clabel.c = 1.5, clegend=0, col.labels=datesdates)
scatterutil.sub(colnames(biovol3m)[j], csub = 1.5, possub = "topleft")
}
par(mfrow = c(1,1))    
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

if(FALSE){
# Save figures as .png, .pdf and .eps
for (j in (c(111,96,50,62)+1)) {
temptab=NULL
for (i in 0:(ndates-1)) {temptab <- cbind(temptab,(biovol3m)[(1+i*nstations):((i+1)*nstations),j])}
rownames(temptab) <- stationsstations
colnames(temptab) <- datesdates
Cairo(800, 980, file=paste(colnames(biovol3m)[j],".png",sep=""), type="png", bg="white", pointsize=16)
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))
table.cont(temptab, abmean.x = FALSE, csi = 2, abline.x = FALSE, coul_rec=couleurs_classes[j], clabel.r = 2, clabel.c = 1.5, clegend=0, col.labels=datesdates)
scatterutil.sub(colnames(biovol3m)[j], csub = 1.5, possub = "topleft")
dev.off() # creates a .png file with the above plot
Cairo(4800, 4800, file=paste(colnames(biovol3m)[j],".pdf",sep=""), type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))
table.cont(temptab, abmean.x = FALSE, csi = 2, abline.x = FALSE, coul_rec=couleurs_classes[j], clabel.r = 2, clabel.c = 1, clegend=0, col.labels=datesdates)
scatterutil.sub(colnames(biovol3m)[j], csub = 1.5, possub = "topleft")
dev.off() # creates a .pdf file with the above plot
Cairo(4800, 4800, file=paste(colnames(biovol3m)[j],sep=""), type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))
table.cont(temptab, abmean.x = FALSE, csi = 2, abline.x = FALSE, coul_rec=couleurs_classes[j], clabel.r = 2, clabel.c = 1, clegend=0, col.labels=datesdates)
scatterutil.sub(colnames(biovol3m)[j], csub = 1.5, possub = "topleft")
dev.off() # creates a .eps file with the above plot
}
par(mfrow = c(1,1))    
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))
}


# Performing the Partial Triadic Analysis
# PTA biovol3m

ktabbiovol3m <- ktab.list.df(lapply(split(cbind(codes$Lettre,biovol3m),codes$Lettre),function(x) {return(x[,-1])}))
row.names(ktabbiovol3m) <- c("06/03/2006","04/04/2006","03/05/2006","07/06/2006","28/06/2006","04/07/2006","24/07/2006","07/08/2006","22/08/2006","05/09/2006","19/09/2006")
#row.names(ktabbiovol3m) <- c("06/03","04/04","03/05","07/06","28/06","04/07","24/07","07/08","22/08","05/09","19/09")
 
ktabbiovol3mscaled <- ktab.list.df(lapply(rapply(lapply(lapply(split(cbind(codes$Lettre,biovol3m),codes$Lettre),function(x) {return(x[,-1])}),scale), function(XX) {apply(XX, c(1,2), function(ll) {if(!is.nan(ll)){ll} else {0}})}, how="replace"),as.data.frame))
row.names(ktabbiovol3mscaled) <- c("06/03/2006","04/04/2006","03/05/2006","07/06/2006","28/06/2006","04/07/2006","24/07/2006","07/08/2006","22/08/2006","05/09/2006","19/09/2006")
#row.names(ktabbiovol3mscaled) <- c("06/03","04/04","03/05","07/06","28/06","04/07","24/07","07/08","22/08","05/09","19/09")


ktabbiovol3mscaled <- ktab.list.df(lapply(rapply(lapply(lapply(split(cbind(codes$Lettre,biovol3m),codes$Lettre),function(x) {return(x[,-1])}),scale), function(XX) {apply(XX, c(1,2), function(ll) {if(!is.nan(ll)){ll} else {0}})}, how="replace"),as.data.frame))
row.names(ktabbiovol3mscaled) <- c("06/03/2006","04/04/2006","03/05/2006","07/06/2006","28/06/2006","04/07/2006","24/07/2006","07/08/2006","22/08/2006","05/09/2006","19/09/2006")




# Same ktab as :
#temp <- lapply(split(cbind(codes$Lettre,biovol3m),codes$Lettre),function(x) {return(x[,-1])})
#w <- rbind.data.frame(temp$G,temp$H,temp$I,temp$J,temp$K,temp$N)
#pca1 <- dudi.pca(w, scal = F, scan = F)
#wit1 <- within(pca1, factor(rep(c("G", "H", "I", "J", "K", "N"), rep(11,6))), scan = F)
#ktaprovi <- ktab.within(wit1, colnames = rep(row.names(temp$G), 6))
#kta4 <- t(ktaprovi)
#kta4$G
#scale(kta4$G)

# With ade4 function
pta1 <- pta(ktabbiovol3mscaled, scan = FALSE, nf=3)
pta1


#Partial triadic analysis

CovV.comp <- function(mat1,mat2) {return(1/nrow(mat1)*sum(diag(t(as.matrix(mat1))%*%as.matrix(mat2))))}
CovV.comp(ktabbiovol3mscaled$G,ktabbiovol3mscaled$G)
CovV.comp(ktabbiovol3mscaled$G,ktabbiovol3mscaled$H)
(CovVs <- matrix(NA,nrow=6,ncol=6,dimnames=list(c("G","H","I","J","K","N"),c("G","H","I","J","K","N"))))
for(ii in 1:6){for(jj in 1:6){CovVs[ii,jj] <- CovV.comp(ktabbiovol3mscaled[[ii]],ktabbiovol3mscaled[[jj]])}}
CovVs
pta1$RV
pta1$RV/CovVs

RV.comp <- function(mat1,mat2) {return(sum(diag(t(as.matrix(mat1))%*%as.matrix(mat2)))/sqrt(sum(diag(t(as.matrix(mat1))%*%as.matrix(mat1)))*sum(diag(t(as.matrix(mat2))%*%as.matrix(mat2)))))}
RV.comp(ktabbiovol3mscaled$G,ktabbiovol3mscaled$G)
RV.comp(ktabbiovol3mscaled$G,ktabbiovol3mscaled$H)
(RVs <- matrix(NA,nrow=6,ncol=6,dimnames=list(c("G","H","I","J","K","N"),c("G","H","I","J","K","N"))))
for(ii in 1:6){for(jj in 1:6){RVs[ii,jj] <- RV.comp(ktabbiovol3mscaled[[ii]],ktabbiovol3mscaled[[jj]])}}
RVs
pta1$RV

(eigendecompCovV <- eigen(x=CovVs, symmetric=TRUE))
(eigendecomp <- eigen(x=RVs, symmetric=TRUE))
(eigenvalues <- eigendecomp$values)
pta1$RV.eig
(eigenvalues/sum(eigenvalues))*100
pta1$RV.eig/sum(pta1$RV.eig)*100
eigendecomp$vectors[, 1]
if (any(eigendecomp$vectors[, 1] < 0)) eigendecomp$vectors[, 1] <- -eigendecomp$vectors[, 1]
eigendecomp$vectors[, 1]
alpha <- eigendecomp$vectors[,1]/sum(eigendecomp$vectors[,1]^2)
names(alpha) <- c("G","H","I","J","K","N")
alpha
tabw_ <- pta1$tabw
names(tabw_) <- pta1$tab.names
tabw_
D <- diag(eigenvalues)
dimnames(D) <- list(c(paste("axis",1:6,sep="")),c(paste("axis",1:6,sep="")))
D
P <- eigendecomp$vectors
dimnames(P) <- list(c("G","H","I","J","K","N"),c(paste("axis",1:6,sep="")))
P
P%*%sqrt(D)


Comp <- 0
for(ii in 1:6){Comp <- Comp+alpha[ii]*as.matrix(ktabbiovol3mscaled[[ii]])}
Comp


Compde <- eigen(Comp%*%t(Comp)/112)
Compde$values[1:10]
dudi.pca(t(Comp),scannf=FALSE, center = FALSE, scale = FALSE)$eig
pta1$eig



Pda <- Compde$vectors[,1:3]
Dda <- diag(Compde$values[1:3])
Gda <- Pda %*% sqrt(Dda)
dimnames(Gda) <- dimnames(pta1$li)
Gda
Gda%*%solve(sqrt(Dda))
Pda
pta1$l1


Fes <- t(Comp)%*%Pda #Coord
Fes
pta1$co
Fes%*%solve(sqrt(Dda)) #normed scores
pta1$c1


which.min(Ges[,1])
which.max(Ges[,1])

which.min(Ges[,2])
which.max(Ges[,2])


FesG <- t(ktabbiovol3mscaled[["G"]])%*%Pda #Coordspecies
FesG
pta1$Tco[1:112,]

GdaG <- 1/112*as.matrix(ktabbiovol3mscaled[["G"]])%*%Fes%*%solve(sqrt(Dda)) #Coord dates
GdaG
pta1$Tli[1:11,]



Gde <- eigen(as.matrix(ktabbiovol3mscaled[["G"]])%*%t(as.matrix(ktabbiovol3mscaled[["G"]]))/112)
Gde$values[1:10]
sepan(ktabbiovol3mscaled,nf=3)$Eig[1:10]

PdasepG <- Gde$vectors[,1:4]
DdasepG <- diag(Gde$values[1:4])
GdasepG <- PdasepG %*% sqrt(DdasepG)
dimnames(GdasepG)[[1]] <- dimnames(pta1$li)[[1]]
dimnames(GdasepG)[[2]] <- c(dimnames(pta1$li)[[2]],"Axis4")
GdasepG
sepan(ktabbiovol3mscaled,nf=4)$Li[1:11,]
PdasepG
GdasepG%*%solve(sqrt(DdasepG))
sepan(ktabbiovol3mscaled,nf=4)$L1[1:11,]

FessepG <- t(ktabbiovol3mscaled[["G"]])%*%PdasepG
FessepG
sepan(ktabbiovol3mscaled,nf=4)$Co[1:112,]
FessepG%*%solve(sqrt(DdasepG))
sepan(ktabbiovol3mscaled,nf=4)$C1[1:112,]


t(as.matrix(GdasepG%*%solve(sqrt(DdasepG))))%*%as.matrix(Pda)
pta1$Tcomp[1:4,]

1/112*t(FessepG%*%solve(sqrt(DdasepG)))%*%as.matrix(Fes%*%solve(sqrt(Dda)))
pta1$Tax[1:4,]


cos2_ <- pta1$cos2
names(cos2_) <- pta1$tab.names
cos2_

coords_ <- pta1$co
dimnames(coords_) <- dimnames(pta1$co)
coords_

coordsdates <- pta1$li
dimnames(coordsdates) <- dimnames(pta1$li)
coordsdates


# Create directory for saving PTA output
dir.create(paste(DataPath,"Graphs\\PTAbiovol\\",sep=""))
setwd(paste(DataPath,"Graphs\\PTAbiovol\\",sep=""))

library(R2HTML)
.HTML.file = file.path(getwd(),"pta_infos.html")

HTML("Table des RVs", "\n", "\n", file ="pta_infos.html", sep="", append = FALSE)
HTML(" ", colnames(pta1$RV), "\n", file ="pta_infos.html", sep="\t", append = TRUE)
HTML(format(pta1$RV, digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML("\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML("Table des Valeurs propres", "\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML(format(pta1$RV.eig, digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML("\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML("Table des Valeurs propres en %", "\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML(format(pta1$RV.eig/sum(pta1$RV.eig), digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML("\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML("Coordonnes", "\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML(" ", colnames(pta1$RV.coo), "\n", file ="pta_infos.html", sep="\t", append = TRUE)
HTML(format(pta1$RV.coo, digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML("\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML("Poids des tableaux", "\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML(format(tabw_, digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML("\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML("Cos2 des tableaux", "\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML(format(cos2_, digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML("\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML("Table des Valeurs propres Compromis", "\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML(format(pta1$eig, digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML("\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML("Table des Valeurs propres Compromis en %", "\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML(format(pta1$eig/sum(pta1$eig), digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML("\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML("Coord Phyto Compromise", "\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML(format(coords_, digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML("\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML("Coord Dates Compromise", "\n", "\n", file ="pta_infos.html", sep="", append = TRUE)
HTML(format(coordsdates_, digits = 3), file = "pta_infos.html", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")

HTML(format(D,digits=3))
HTML(format(P,digits=1))
HTML(format(P%*%sqrt(D),digits=1))
HTML(format(pta1$RV.coo,digits=3))

HTML(Ges)
HTML(Gda)
HTML(pta1$li)


# Saves html but with .xls extension since Excel easily reads tables in .html format

(splitsplit <- pta1$TL$T)
levels(splitsplit) <- pta1$tab.names
splitpta1 <- split(pta1$Tli,splitsplit)

for (iinom in levels(splitsplit)) {
HTML(splitpta1[[iinom]], paste("coords_station_intra_",iinom,".xls",sep=""), colNames = TRUE, sheet = 1, from = 1, rowNames = NA )
}

rm(splitsplit,splitpta1)











nombre_axe <- 3



##########   Axe 1 et 2

axe1 <- 1
axe2 <- 2

plot.pta(pta1, xax=axe1, yax=axe2, csub=3, clabel=1.5, cpoints=2)

plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1, csub=3, option=2, cpoints=2)
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")


par(mar = c(3, 3, 2, 1) + 0.1, mgp=c(2,1,0))
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=4)
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

kplot.pta(pta1, xax=axe1, yax=axe2, edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=2, cpoints=2)

kplot.pta(pta1, xax=axe1, yax=axe2, edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=0, which.graph=1, mfrow=c(1,1), clabel=2, cpoints=2)
kplot.pta(pta1, xax=axe1, yax=axe2, edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=0, which.graph=2, mfrow=c(1,1), clabel=1.5, cpoints=2)
kplot.pta(pta1, xax=axe1, yax=axe2, edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=0, which.graph=3, mfrow=c(1,1), clabel=2, cpoints=2)
kplot.pta(pta1, xax=axe1, yax=axe2, edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=0, which.graph=4, mfrow=c(1,1), clabel=2, cpoints=2)

dir.create(paste(DataPath,"Graphs\\PTAbiovol\\Axes12\\",sep=""))
setwd(paste(DataPath,"Graphs\\PTAbiovol\\Axes12\\",sep=""))


par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_total.png", type="png", bg="white", pointsize=12)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)
dev.off() 
Cairo(4800, 4800, file="biovol_total.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)
dev.off() 
Cairo(4800, 4800, file="biovol_total", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_interstucture.png", type="png", bg="white", pointsize=12)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
dev.off() 
Cairo(4800, 4800, file="biovol_interstucture.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
dev.off() 
Cairo(4800, 4800, file="biovol_interstucture", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_compromis_1.png", type="png", bg="white", pointsize=12)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2)
dev.off() 
Cairo(4800, 4800, file="biovol_compromis_1.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2)
dev.off() 
Cairo(4800, 4800, file="biovol_compromis_1", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_compromis_2.png", type="png", bg="white", pointsize=12)
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
dev.off() 
Cairo(4800, 4800, file="biovol_compromis_2.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
dev.off() 
Cairo(4800, 4800, file="biovol_compromis_2", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_weights.png", type="png", bg="white", pointsize=12)
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=4, arr=FALSE)
dev.off() 
Cairo(4800, 4800, file="biovol_weights.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=4, arr=FALSE)
dev.off() 
Cairo(4800, 4800, file="biovol_weights", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=4, arr=FALSE)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))




par(mfrow = c(1,1))
Cairo(800, 800, file="biovol1_station_reprod_inter_2.png", type="png", bg="white", pointsize=12)
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
dev.off() 
Cairo(4800, 4800, file="biovol1_station_reprod_inter_2.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
dev.off() 
Cairo(4800, 4800, file="biovol1_station_reprod_inter_2", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))



nomdesgraphes <- c("biovol1_station_reprod_inter_coorcicle_1_","biovol1_station_reprod_inter_dates_","biovol1_station_reprod_inter_biovol_","biovol1_station_reprod_inter_coorcicle_2_")
nomdesstations <- stationsstations
for (i in 1:4) {
for (j in 1:nstations) {
Cairo(800, 800, file=paste("",nomdesgraphes[i],nomdesstations[j],".png"), type="png", bg="white", pointsize=12)
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=c(0,0,0,0)[i], which.graph=i, which.tab=j, mfrow=c(1,1), clabel=c(2,1.5,0,2)[i], cpoints=2, len = .05)
dev.off()
Cairo(4800, 4800, file=paste("",nomdesgraphes[i],nomdesstations[j],".pdf"), type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=c(0,0,0,0)[i], which.graph=i, which.tab=j, mfrow=c(1,1), clabel=c(2,1.5,0,2)[i], cpoints=2, len = .05)
dev.off()
Cairo(4800, 4800, file=paste("",nomdesgraphes[i],nomdesstations[j]), type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=12, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-3,3), ylim_var=c(-3,3), xlim_ind=c(-1,1), ylim_ind=c(-1,1), coulvar=couleurs_classes, clabel_cor=c(0,0,0,0)[i], which.graph=i, which.tab=j, mfrow=c(1,1), clabel=c(2,1.5,0,2)[i], cpoints=2, len = .05)
dev.off()
}
}    






##########   Axe 1 et 3

axe1 <- 1
axe2 <- 3

plot.pta(pta1, xax=axe1, yax=axe2, , clabel=1.5, csub=3)

plot.pta(pta1, xax=axe1, yax=axe2, , clabel=1.5, csub=3, option=1)
plot.pta(pta1, xax=axe1, yax=axe2, , clabel=0, csub=3, option=2, cpoints=2)
plot.pta(pta1, xax=axe1, yax=axe2, , clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
plot.pta(pta1, xax=axe1, yax=axe2, , clabel=1.5, csub=3, option=4)
kplot.pta(pta1, xax=axe1, yax=axe2, ,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.5), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
kplot.pta(pta1, xax=axe1, yax=axe2, ,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.7), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, mfrow=c(1,1), clabel=0, cpoints=2)

dir.create(paste(DataPath,"Graphs\\PTAbiovol\\Axes13\\",sep=""))
setwd(paste(DataPath,"Graphs\\PTAbiovol\\Axes13\\",sep=""))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_total.png", type="png", bg="white", pointsize=16)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_total.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_total", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_interstucture.png", type="png", bg="white", pointsize=16)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_interstucture.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_interstucture", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_compromis_1.png", type="png", bg="white", pointsize=16)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_compromis_1.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_compromis_1", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_compromis_2.png", type="png", bg="white", pointsize=16)
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_compromis_2.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_compromis_2", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))




par(mfrow = c(1,1))
Cairo(800, 800, file="biovol1_station_reprod_inter_2.png", type="png", bg="white", pointsize=16)
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.7), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol1_station_reprod_inter_2.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.7), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol1_station_reprod_inter_2", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.7), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

nomdesgraphes <- c("biovol1_station_reprod_inter_coorcicle_1_","biovol1_station_reprod_inter_dates_","biovol1_station_reprod_inter_biovol_","biovol1_station_reprod_inter_coorcicle_2_")
nomdesstations <- stationsstations
for (i in 1:4) {
for (j in 1:nstations) {
Cairo(800, 800, file=paste("",nomdesgraphes[i],nomdesstations[j],".png"), type="png", bg="white", pointsize=16)
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.5), coulvar=couleurs_classes, clabel_cor=0, which.graph=i, which.tab=j, mfrow=c(1,1), clabel=0, cpoints=2)
dev.off() # creates a file "espce.png" with the above plot
Cairo(4800, 4800, file=paste("",nomdesgraphes[i],nomdesstations[j],".pdf"), type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.5), coulvar=couleurs_classes, clabel_cor=0, which.graph=i, which.tab=j, mfrow=c(1,1), clabel=0, cpoints=2)
dev.off() # creates a file "espce.ps" with the above plot
Cairo(4800, 4800, file=paste("",nomdesgraphes[i],nomdesstations[j]), type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.5), coulvar=couleurs_classes, clabel_cor=0, which.graph=i, which.tab=j, mfrow=c(1,1), clabel=0, cpoints=2)
dev.off() # creates a file "espce.ps" with the above plot
}
}    



##########   Axe 2 et 3
axe1 <- 2
axe2 <- 3

plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)

plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2)
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=4)
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.5), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.7), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, mfrow=c(1,1), clabel=0, cpoints=2)

dir.create(paste(DataPath,"Graphs\\PTAbiovol\\Axes23\\",sep=""))
setwd(paste(DataPath,"Graphs\\PTAbiovol\\Axes23\\",sep=""))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_total.png", type="png", bg="white", pointsize=16)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_total.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_total", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_interstucture.png", type="png", bg="white", pointsize=16)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_interstucture.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_interstucture", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=1.5, csub=3, option=1)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_compromis_1.png", type="png", bg="white", pointsize=16)
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2,posigraph2="bottomcenter")
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_compromis_1.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2,posigraph2="bottomcenter")
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_compromis_1", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel=0, csub=3, option=2, cpoints=2,posigraph2="bottomcenter")
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

par(mfrow = c(1,1))
Cairo(800, 800, file="biovol_compromis_2.png", type="png", bg="white", pointsize=16)
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_compromis_2.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol_compromis_2", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot.pta(pta1, xax=axe1, yax=axe2, clabel_cor=0, csub=3, cpoint=2, option=3, arr=FALSE, coulvar=couleurs_classes, possub3="bottomright")
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))




par(mfrow = c(1,1))
Cairo(800, 800, file="biovol1_station_reprod_inter_2.png", type="png", bg="white", pointsize=16)
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.7), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol1_station_reprod_inter_2.pdf", type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.7), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
dev.off() # creates a file "espce.pdf" with the above plot
Cairo(4800, 4800, file="biovol1_station_reprod_inter_2", type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.7), coulvar=couleurs_classes, clabel_cor=0, which.graph=1:4, clabel=0, cpoints=2)
dev.off() # creates a file "espce.ps" with the above plot
par(mfrow = c(1,1))

nomdesgraphes <- c("biovol1_station_reprod_inter_coorcicle_1_","biovol1_station_reprod_inter_dates_","biovol1_station_reprod_inter_biovol_","biovol1_station_reprod_inter_coorcicle_2_")
nomdesstations <- stationsstations
for (i in 1:4) {
for (j in 1:nstations) {
Cairo(800, 800, file=paste("",nomdesgraphes[i],nomdesstations[j],".png"), type="png", bg="white", pointsize=16)
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.5), coulvar=couleurs_classes, clabel_cor=0, which.graph=i, which.tab=j, mfrow=c(1,1), clabel=0, cpoints=2)
dev.off() # creates a file "espce.png" with the above plot
Cairo(4800, 4800, file=paste("",nomdesgraphes[i],nomdesstations[j],".pdf"), type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.5), coulvar=couleurs_classes, clabel_cor=0, which.graph=i, which.tab=j, mfrow=c(1,1), clabel=0, cpoints=2)
dev.off() # creates a file "espce.ps" with the above plot
Cairo(4800, 4800, file=paste("",nomdesgraphes[i],nomdesstations[j]), type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
kplot.pta(pta1, xax=axe1, yax=axe2,edge=FALSE, arr=FALSE, cpoint=2, xlim_var=c(-1,1), ylim_var=c(-1,1), xlim_ind=c(-10,15), ylim_ind=c(-10,7.5), coulvar=couleurs_classes, clabel_cor=0, which.graph=i, which.tab=j, mfrow=c(1,1), clabel=0, cpoints=2)
dev.off() # creates a file "espce.ps" with the above plot
}
}    



























nombre_axe <- 3

cex00 <- .8

couleurs_axes <- couleurs_classes
names(couleurs_axes) <- biovol_classes[,1]

library(SuppDists)
res.PCAc <- (pta1$co)[,1:nombre_axe]
dimnames(res.PCAc)[[2]] <- paste("Dim." ,1:nombre_axe, sep="")
for(jjjj in 1:nombre_axe) {
for(kkkk in dimnames(pta1$tab)[[2]]) {
res.PCAc[kkkk,jjjj] <- cor((pta1$tab)[,kkkk],(pta1$li)[,jjjj], method = c("kendall"))
}
}
rm(jjjj)
rm(kkkk)

res.PCAc <- as.matrix(res.PCAc)
(quantkendall <- qKendall(c(0.005,0.995),N=length(pta1$lw)))
apply(abs(res.PCAc)>quantkendall[2],2,sum)
full_names <- dimnames(res.PCAc)[[1]]

names_PCAc_cor <- dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]

temptemp <- sapply((biovol_Full)[,-1],sum,na.rm=T)/sum((biovol_Full)[,-1],na.rm=T)
sum(temptemp[dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]])*100

temptemp2 <- sapply((phyto_Full)[,-1],sum,na.rm=T)/sum((phyto_Full)[,-1],na.rm=T)
sum(temptemp2[dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]],na.rm=T)*100

dir.create(paste(DataPath,"Graphs\\PTAbiovol\\Especes_axes_Kendall\\",sep=""))
setwd(paste(DataPath,"Graphs\\PTAbiovol\\Especes_axes_Kendall\\",sep=""))

cat("Espces et axes, seuil 1%", "\n", "\n", file ="espces_axes.txt", sep="", append = FALSE)
for(jjjj in 1:dim(res.PCAc)[2]) {
cat(paste("Espces et axe",jjjj), "\n", "\n", file ="espces_axes.txt", sep="", append = TRUE)
if(length(res.PCAc[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],jjjj]) >1 ) {
write.table(res.PCAc[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],jjjj], file ="espces_axes.txt", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")
cat("\n", "\n", file ="espces_axes.txt", sep="", append = TRUE)
}
if(length(res.PCAc[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],jjjj]) == 1) {
write.table(cbind(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],res.PCAc[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],jjjj]), file ="espces_axes.txt", append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = FALSE, qmethod = "double")
cat("\n", "\n", file ="espces_axes.txt", sep="", append = TRUE)
}
}
rm("jjjj")
cat(paste(paste("Pourcentage biovolume par espce (axes 1  ",dim(res.PCAc)[2],")",sep=""),"\n"), file ="espces_axes.txt", sep="", append = TRUE)
cat(sum(temptemp[dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]])*100, file ="espces_axes.txt", sep="", append = TRUE)

rm("temptemp")
rm("temptemp2")





#Kendall correlations

#Compromise

dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0] <- abbreviate(dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0],15)
dimnames(res.PCAc)[[1]]
names_PCAc_cor <- dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]

couleurs_axes <- couleurs_classes
names(couleurs_axes) <- dimnames(res.PCAc)[[1]]


qKendall(c(0.005,0.995),N=nrow(Gda))
qKendall(c(0.025,0.975),N=nrow(Gda))

which.min(-Ges[,1])
res.PCAc[which.min(-Ges[,1]),]
which.max(-Ges[,1])
res.PCAc[which.max(-Ges[,1]),]

which.min(-Ges[,2])
res.PCAc[which.min(-Ges[,2]),]
which.max(-Ges[,2])
res.PCAc[which.max(-Ges[,2]),]


par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:dim(res.PCAc)[2]) {
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.25,1.3),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
}
}
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- 1.75
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:dim(res.PCAc)[2]) {
par(mfrow = c(1,1))
Cairo(1500, 1600, file=paste("axe_",jjjj,"_biovol_especes.png",sep=""), type="png", bg="white", pointsize=16)
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.25,1.3),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
}
}
dev.off() # creates a file "espce.pdf" with the above plot
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- 1
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:dim(res.PCAc)[2]) {
par(mfrow = c(1,1))
Cairo(5600, 7200, paste("axe_",jjjj,"_biovol_especes.pdf",sep=""), type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.7,1.7),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
}
}
dev.off() # creates a file "espce.pdf" with the above plot
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- 1
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:dim(res.PCAc)[2]) {
par(mfrow = c(1,1))
Cairo(5600, 7200, file=paste("axe_",jjjj,"_biovol_especes",sep=""), type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.7,1.7),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
}
}
dev.off() # creates a file "espce.ps" with the above plot
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))


cex00 <- 0.8
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:dim(res.PCAc)[2]) {
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.25,1.3),ylab="",xlab="",yaxt="n",mar=c(1, 1, 1, 1))
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]],font=4)
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]],font=4)
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
}
}
}                                           
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))


cex00 <- 1.75
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:dim(res.PCAc)[2]) {
par(mfrow = c(1,1))
Cairo(1500, 1600, file=paste("axe_",jjjj,"_biovol_especes_color.png",sep=""), type="png", bg="white", pointsize=16)
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.25,1.3),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]],font=4)
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]],font=4)
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
}
}
dev.off() # creates a file "espce.pdf" with the above plot
}
rm("jjjj")

par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- 1
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:dim(res.PCAc)[2]) {
par(mfrow = c(1,1))
Cairo(5600, 7200, paste("axe_",jjjj,"_biovol_especes_color.pdf",sep=""), type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.7,1.7),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]],font=4)
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]],font=4)
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
}
}
dev.off() # creates a file "espce.pdf" with the above plot
}
rm("jjjj")

cex00 <- 1
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:dim(res.PCAc)[2]) {
par(mfrow = c(1,1))
Cairo(5600, 7200, file=paste("axe_",jjjj,"_biovol_especes_color",sep=""), type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.7,1.7),ylab="",xlab="",yaxt="n",mar=c(0, 0, 0, 0) + 0.1)
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]],font=4)
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]],font=4)
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
}
}
dev.off() # creates a file "espce.ps" with the above plot
}
rm("jjjj")


par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))
dimnames(res.PCAc)[[1]] <- full_names
HTML(x=cbind(abbreviate(dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0],15),dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]),file="Abreviations_liste.xls",colNames=TRUE)


















# Intrastructure

nombre_axe <- 3

couleurs_axes <- couleurs_classes
names(couleurs_axes) <- biovol_classes[,1]
listestations <- c("G","H","I","J","K","N")


for(stationnum in 1:6){
station <- listestations[stationnum]
print(station)

dir.create(paste(DataPath,"Graphs\\PTAbiovol\\Especes_axes_Kendall\\",station,"\\",sep=""))
setwd(paste(DataPath,"Graphs\\PTAbiovol\\Especes_axes_Kendall\\",station,"\\",sep=""))

cex00 <- 0.8

library(SuppDists)
res.PCAc <- (pta1$Tco)[(pta1$TC$T==stationnum),1:nombre_axe]
rownames(res.PCAc) <- unlist(strsplit(rownames((pta1$Tco)[(pta1$TC$T==stationnum),1:nombre_axe]),paste(".",stationnum,sep="")))
dimnames(res.PCAc)[[2]] <- paste("Dim." ,1:nombre_axe, sep="")
for(jjjj in 1:nombre_axe) {
for(kkkk in dimnames(ktabbiovol3mscaled[[station]])[[2]]) {
res.PCAc[kkkk,jjjj] <- cor(ktabbiovol3mscaled[[station]][,kkkk],((pta1$Tli)[(pta1$TL$T==stationnum),1:nombre_axe])[,jjjj], method = c("kendall"))
}
}
rm(jjjj)
rm(kkkk)
res.PCAc <- as.matrix(res.PCAc)
absent.res.PCAc <- rownames(res.PCAc[apply(is.na(res.PCAc),1,sum)>0,])
res.PCAc <- res.PCAc[apply(is.na(res.PCAc),1,sum)==0,]
(quantkendall <- qKendall(c(0.005,0.995),N=length(pta1$lw)))
apply(abs(res.PCAc)>quantkendall[2],2,sum)
full_names <- dimnames(res.PCAc)[[1]]

names_PCAc_cor <- dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]

temptemp <- sapply((biovol_Full)[,-1],sum,na.rm=T)/sum((biovol_Full)[,-1],na.rm=T)
sum(temptemp[dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]])*100

temptemp2 <- sapply((phyto_Full)[,-1],sum,na.rm=T)/sum((phyto_Full)[,-1],na.rm=T)
sum(temptemp2[dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]],na.rm=T)*100

cat("Espces et axes, seuil 1%", "\n", "\n", file =paste(station,"_espces_axes.txt",sep=""), sep="", append = FALSE)
for(jjjj in 1:1) {
cat(paste("Espces et axe",jjjj), "\n", "\n", file =paste(station,"_espces_axes.txt",sep=""), sep="", append = TRUE)
if(length(res.PCAc[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],jjjj]) >1 ) {
write.table(res.PCAc[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],jjjj], file =paste(station,"_espces_axes.txt",sep=""), append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = TRUE,
            col.names = FALSE, qmethod = "double")
cat("\n", "\n", file =paste(station,"_espces_axes.txt",sep=""), sep="", append = TRUE)
}
if(length(res.PCAc[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],jjjj]) == 1) {
write.table(cbind(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],res.PCAc[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],jjjj]), file =paste(station,"_espces_axes.txt",sep=""), append = TRUE, quote = TRUE, sep = "\t",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = FALSE, qmethod = "double")
cat("\n", "\n", file =paste(station,"_espces_axes.txt",sep=""), sep="", append = TRUE)
}
}
rm("jjjj")
cat(paste(paste("Pourcentage biovolume par espce (axes 1  ",1,")",sep=""),"\n"), file =paste(station,"_espces_axes.txt",sep=""), sep="", append = TRUE)
cat(sum(temptemp[dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]])*100, file =paste(station,"_espces_axes.txt",sep=""), sep="", append = TRUE)

rm("temptemp")
rm("temptemp2")

dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0] <- abbreviate(dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0],15)
dimnames(res.PCAc)[[1]]
names_PCAc_cor <- dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]

couleurs_axes <- couleurs_classes
names(couleurs_axes) <- dimnames(res.PCAc)[[1]]

par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))
for(jjjj in 1:1) {
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.15,1.25),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[2] %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[Z]],pos=2+2*((1+names_to_plot[2]) %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
}
}
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))


cex00 <- 1.75
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:1) {
par(mfrow = c(1,1))
Cairo(1500, 1600, file=paste(station,"_axe_",jjjj,"_biovol_especes.png",sep=""), type="png", bg="white", pointsize=16)
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.15,1.25),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[2] %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[2]) %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
}
}
dev.off() # creates a file "espce.pdf" with the above plot
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- 1
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:1) {
par(mfrow = c(1,1))
Cairo(5600, 7200, paste(station,"_axe_",jjjj,"_biovol_especes.pdf",sep=""), type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.5,1.6),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[2] %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[2]) %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
}
}
dev.off() # creates a file "espce.pdf" with the above plot
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- 1
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:1) {
par(mfrow = c(1,1))
Cairo(5600, 7200, file=paste(station,"_axe_",jjjj,"_biovol_especes",sep=""), type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.5,1.6),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4)
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19)
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[2] %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[2]) %% 2),cex=cex00,font=4)
points(names_to_plot[1],names_to_plot[2],pch=19)
}
}
}
dev.off() # creates a file "espce.ps" with the above plot
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- .8
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:1) {
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.15,1.25),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
}
}
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- 1.75
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:1) {
par(mfrow = c(1,1))
Cairo(1500, 1600, file=paste(station,"_axe_",jjjj,"_biovol_especes_color.png",sep=""), type="png", bg="white", pointsize=16)
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.15,1.25),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
}
}
dev.off() # creates a file "espce.pdf" with the above plot
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- 1
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:1) {
par(mfrow = c(1,1))
Cairo(5600, 7200, paste(station,"_axe_",jjjj,"_biovol_especes_color.pdf",sep=""), type="pdf", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.5,1.6),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
}
}
dev.off() # creates a file "espce.pdf" with the above plot
}
rm("jjjj")
par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

cex00 <- 1
par(mar = c(2, 1, 1, 1) + 0.1, mgp=c(1,.5,0))

for(jjjj in 1:1) {
par(mfrow = c(1,1))
Cairo(5600, 7200, file=paste(station,"_axe_",jjjj,"_biovol_especes_color",sep=""), type="ps", bg="white", dpi=600, pagecentre=TRUE, pointsize=16, encoding="ISOLatin1")
plot(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor),xlim=c(-1.5,1.6),ylab="",xlab="",yaxt="n")
abline(v=qKendall(0.995,N=length(pta1$lw)),lty=2,lwd=2)
abline(v=0,lty=1,lwd=1)
abline(v=qKendall(0.005,N=length(pta1$lw)),lty=2,lwd=2)
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >0) {
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) >1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
for(kkkk in 1:nrow(names_to_plot)) {
if(names_to_plot[kkkk,1] > 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*(names_to_plot[kkkk,2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
if(names_to_plot[kkkk,1] < 0) {
text(names_to_plot[kkkk,1],names_to_plot[kkkk,2],labels=rownames(names_to_plot)[kkkk],pos=2+2*((1+names_to_plot[kkkk,2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
points(names_to_plot[kkkk,1],names_to_plot[kkkk,2],pch=19,col=couleurs_axes[rownames(names_to_plot)[kkkk]])
}
}
rm("kkkk")
}
if(length(dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0]) ==1) {
names_to_plot <- cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor))[dimnames(res.PCAc)[[1]][(abs(res.PCAc)>quantkendall[2])[,jjjj]>0],]
if(names_to_plot[1] > 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*(names_to_plot[2] %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
if(names_to_plot[1] < 0) {
text(names_to_plot[1],names_to_plot[2],labels=rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]],pos=2+2*((1+names_to_plot[2]) %% 2),cex=cex00,font=4,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
points(names_to_plot[1],names_to_plot[2],pch=19,col=couleurs_axes[rownames(cbind(sort(res.PCAc[names_PCAc_cor,jjjj]),1:length(names_PCAc_cor)))[names_to_plot[2]]])
}
}
}
dev.off() # creates a file "espce.ps" with the above plot
}
rm("jjjj")

par(mar = c(5, 4, 4, 2) + 0.1, mgp=c(3,1,0))

dimnames(res.PCAc)[[1]] <- full_names
HTML(x=cbind(abbreviate(dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0],15),dimnames(res.PCAc)[[1]][apply(abs(res.PCAc)>quantkendall[2],1,sum)>0]),file=paste(station,"_abreviation_liste.xls",sep=""),colNames=FALSE)
}
rm(station)



